@@ -5,7 +5,7 @@ import threading
 class MessageChain:
     """
     An object containing the initial request sent via the make_request method,
-    together with all request/response pairs (Handling objects) processed by
+    and all request/response pairs (Handling objects) processed by
     DeproxyEndpoint objects.
     """
     def __init__(self, handler_function):
@@ -26,6 +26,6 @@ class MessageChain:
 
     def __repr__(self):
         return ('MessageChain(handler_function=%r, sent_request=%r, '
-                'handlings=%r, received_response=%r)' %
+                'handlings=%r, received_response=%r, orphaned_handlings=%r)' %
                 (self.handler_function, self.sent_request, self.handlings,
-                 self.received_response))
+                 self.received_response, self.orphaned_handlings))
